@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of the python-chess library.
-# Copyright (C) 2012-2018 Niklas Fiekas <niklas.fiekas@backscattering.de>
+# Copyright (C) 2012-2019 Niklas Fiekas <niklas.fiekas@backscattering.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,21 +18,32 @@
 
 import chess
 
-from chess.engine import EngineTerminatedException
-from chess.engine import EngineStateException
-from chess.engine import MockProcess
-from chess.engine import PopenProcess
-from chess.engine import SpurProcess
-from chess.engine import Option
-from chess.engine import OptionMap
-from chess.engine import LOGGER
-from chess.engine import FUTURE_POLL_TIMEOUT
-from chess.engine import _popen_engine
-from chess.engine import _spur_spawn_engine
+from chess._engine import EngineTerminatedException
+from chess._engine import EngineStateException
+from chess._engine import MockProcess
+from chess._engine import PopenProcess
+from chess._engine import SpurProcess
+from chess._engine import Option
+from chess._engine import OptionMap
+from chess._engine import LOGGER
+from chess._engine import FUTURE_POLL_TIMEOUT
+from chess._engine import _popen_engine
+from chess._engine import _spur_spawn_engine
 
 import collections
 import concurrent.futures
 import threading
+import warnings
+import textwrap
+
+
+warnings.warn(textwrap.dedent("""\
+    The chess.uci module is deprecated in favor of
+    chess.engine <https://python-chess.readthedocs.io/en/latest/engine.html>.
+
+    Please consider updating and open an issue
+    <https://github.com/niklasf/python-chess/issues/new> if your use case
+    is not covered by the new API."""), DeprecationWarning, stacklevel=2)
 
 
 class Score(collections.namedtuple("Score", "cp mate")):
