@@ -25,6 +25,7 @@ class SuicideBoard(chess.Board):
 
     aliases = ["Suicide", "Suicide chess"]
     uci_variant = "suicide"
+    xboard_variant = "suicide"
 
     tbw_suffix = ".stbw"
     tbz_suffix = ".stbz"
@@ -176,6 +177,7 @@ class GiveawayBoard(SuicideBoard):
 
     aliases = ["Giveaway", "Giveaway chess", "Anti", "Antichess", "Anti chess"]
     uci_variant = "giveaway"
+    xboard_variant = "giveaway"
     starting_fen = "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w - - 0 1"
 
     tbw_suffix = ".gtbw"
@@ -208,6 +210,7 @@ class AtomicBoard(chess.Board):
 
     aliases = ["Atomic", "Atom", "Atomic chess"]
     uci_variant = "atomic"
+    xboard_variant = "atomic"
 
     tbw_suffix = ".atbw"
     tbz_suffix = ".atbz"
@@ -326,6 +329,7 @@ class KingOfTheHillBoard(chess.Board):
 
     aliases = ["King of the Hill", "KOTH"]
     uci_variant = "kingofthehill"
+    xboard_variant = "kingofthehill"  # Unofficial
 
     tbw_suffix = tbz_suffix = None
     tbw_magic = tbz_magic = None
@@ -347,6 +351,7 @@ class RacingKingsBoard(chess.Board):
 
     aliases = ["Racing Kings", "Racing", "Race", "racingkings"]
     uci_variant = "racingkings"
+    xboard_variant = "racingkings"  # Unofficial
     starting_fen = "8/8/8/8/8/8/krbnNBRK/qrbnNBRQ w - - 0 1"
 
     tbw_suffix = tbz_suffix = None
@@ -428,6 +433,7 @@ class HordeBoard(chess.Board):
 
     aliases = ["Horde", "Horde chess"]
     uci_variant = "horde"
+    xboard_variant = "horde"  # Unofficial
     starting_fen = "rnbqkbnr/pppppppp/8/1PP2PP1/PPPPPPPP/PPPPPPPP/PPPPPPPP/PPPPPPPP w kq - 0 1"
 
     tbw_suffix = tbz_suffix = None
@@ -475,6 +481,7 @@ class ThreeCheckBoard(chess.Board):
 
     aliases = ["Three-check", "Three check", "Threecheck", "Three check chess"]
     uci_variant = "3check"
+    xboard_variant = "3check"
     starting_fen = "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 3+3 0 1"
 
     tbw_suffix = tbz_suffix = None
@@ -560,8 +567,8 @@ class ThreeCheckBoard(chess.Board):
 
     def epd(self, shredder=False, en_passant="legal", promoted=None, **operations):
         epd = [super().epd(shredder=shredder, en_passant=en_passant, promoted=promoted),
-               "%d+%d" % (max(self.remaining_checks[chess.WHITE], 0),
-                          max(self.remaining_checks[chess.BLACK], 0))]
+               "{:d}+{:d}".format(max(self.remaining_checks[chess.WHITE], 0),
+                                  max(self.remaining_checks[chess.BLACK], 0))]
         if operations:
             epd.append(self._epd_operations(operations))
         return " ".join(epd)
@@ -648,6 +655,7 @@ class CrazyhouseBoard(chess.Board):
 
     aliases = ["Crazyhouse", "Crazy House", "House", "ZH"]
     uci_variant = "crazyhouse"
+    xboard_variant = "crazyhouse"
     starting_fen = "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR[] w KQkq - 0 1"
 
     tbw_suffix = tbz_suffix = None
@@ -818,7 +826,7 @@ class CrazyhouseBoard(chess.Board):
     def epd(self, shredder=False, en_passant="legal", promoted=None, **operations):
         epd = super().epd(shredder=shredder, en_passant=en_passant, promoted=promoted)
         board_part, info_part = epd.split(" ", 1)
-        return "%s[%s%s] %s" % (board_part, str(self.pockets[chess.WHITE]).upper(), str(self.pockets[chess.BLACK]), info_part)
+        return "{}[{}{}] {}".format(board_part, str(self.pockets[chess.WHITE]).upper(), str(self.pockets[chess.BLACK]), info_part)
 
     def copy(self, stack=True):
         board = super().copy(stack=stack)
